@@ -157,122 +157,120 @@ video_option_setup_list = [
     #   compare codes 18 and 396)
     #
     # Dummy extractor codes - progressive scan resolutions
-    '144p',     'Any format [144p]',                False,
-    '240p',     'Any format [240p]',                False,
-    '360p',     'Any format [360p]',                False,
-    '480p',     'Any format [480p]',                False,
-    '720p',     'Any format [720p]',                False,
-    '720p60',   'Any format [720p 60fps]',          False,
-    '1080p',    'Any format [1080p]',               False,
-    '1080p60',  'Any format [1080p 60fps]',         False,
-    '1440p',    'Any format [1440p]',               False,
-    '1440p60',  'Any format [1440p 60fps]',         False,
-    '2160p',    'Any format [2160p]',               False,
-    '2160p60',  'Any format [2160p 60fps]',         False,
-    '4320p',    'Any format [4320p]',               False,
-    '4320p60',  'Any format [4320p 60fps]',         False,
+    '144p',     'Any format [144p]',                        False,
+    '240p',     'Any format [240p]',                        False,
+    '360p',     'Any format [360p]',                        False,
+    '480p',     'Any format [480p]',                        False,
+    '720p',     'Any format [720p]',                        False,
+    '720p60',   'Any format [720p 60fps]',                  False,
+    '1080p',    'Any format [1080p]',                       False,
+    '1080p60',  'Any format [1080p 60fps]',                 False,
+    '1440p',    'Any format [1440p]',                       False,
+    '1440p60',  'Any format [1440p 60fps]',                 False,
+    '2160p',    'Any format [2160p]',                       False,
+    '2160p60',  'Any format [2160p 60fps]',                 False,
+    '4320p',    'Any format [4320p]',                       False,
+    '4320p60',  'Any format [4320p 60fps]',                 False,
     # Dummy extractor codes - other
-    # v1.5.029 - .m4a files can be downloaded directly from YouTube (unlike
-    #   other audio file formats, for which we need the whole video); so treat
-    #   .m4a like a video format 
-    '3gp',      '3gp',                              False,
-    'flv',      'flv',                              False,
-    'm4a',      'm4a',                              False,
-    'mp4',      'mp4',                              False,
-    'webm',     'webm',                             False,
+    '3gp',      '3gp',                                      False,
+    'flv',      'flv',                                      False,
+    'm4a',      'm4a',                                      True,
+    'mp4',      'mp4',                                      False,
+    'webm',     'webm',                                     False,
     # Real extractor codes
-    '17',       '3gp [144p]',                       False,
-    '36',       '3gp [240p]',                       False,
-    '5',        'flv [240p]',                       False,
-    '6',        'flv [270p]',                       False,
-    '34',       'flv [360p]',                       False,
-    '35',       'flv [480p]',                       False,
+    '17',       '3gp [144p] <17>',                          False,
+    '36',       '3gp [240p] <36>',                          False,
+    '5',        'flv [240p] <5>',                           False,
+    '6',        'flv [270p] <6>',                           False,
+    '34',       'flv [360p] <34>',                          False,
+    '35',       'flv [480p] <35>',                          False,
     # v1.3.037 - not sure whether the HLS format codes should be added here, or
     #   not. 'hls' has not been added as a dummy extractor code because
     #   youtube-dl doesn't support that
-    '151',      'hls [72p]',                        False,
-    '132',      'hls [240p]',                       False,
-    '92',       'hls [240p] (3D)',                  False,
-    '93',       'hls [360p] (3D)',                  False,
-    '94',       'hls [480p] (3D)',                  False,
-    '95',       'hls [720p] (3D)',                  False,
-    '96',       'hls [1080p]',                      False,
-    '139',      'm4a 48k (DASH Audio)',             False,
-    '140',      'm4a 128k (DASH Audio)',            False,
-    '141',      'm4a 256k (DASH Audio)',            False,
-    '18',       'mp4 [360p]',                       False,
-    '22',       'mp4 [720p]',                       False,
-    '37',       'mp4 [1080p]',                      False,
-    '38',       'mp4 [4K]',                         False,
-    '160',      'mp4 [144p] (DASH Video)',          False,
-    '133',      'mp4 [240p] (DASH Video)',          False,
-    '134',      'mp4 [360p] (DASH Video)',          False,
-    '135',      'mp4 [480p] (DASH Video)',          False,
-    '136',      'mp4 [720p] (DASH Video)',          False,
-    '298',      'mp4 [720p 60fps] (DASH Video)',    False,
-    '137',      'mp4 [1080p] (DASH Video)',         False,
-    '299',      'mp4 [1080p 60fps] (DASH Video)',   False,
-    '264',      'mp4 [1440p] (DASH Video)',         False,
-    '138',      'mp4 [2160p] (DASH Video)',         False,
-    '266',      'mp4 [2160p 60fps] (DASH Video)',   False,
-    '82',       'mp4 [360p] (3D)',                  False,
-    '83',       'mp4 [480p] (3D)',                  False,
-    '84',       'mp4 [720p] (3D)',                  False,
-    '85',       'mp4 [1080p] (3D)',                 False,
-    '394',      'mp4 [144p] <394>',                 False,
-    '395',      'mp4 [240p] <395>',                 False,
-    '396',      'mp4 [360p] <396>',                 False,
-    '397',      'mp4 [480p] <397>',                 False,
-    '398',      'mp4 [720p] <398>',                 False,
-    '399',      'mp4 [1080p] <399>',                False,
-    '400',      'mp4 [1440p] <400>',                False,
-    '401',      'mp4 [2160p] <401>',                False,
-    '402',      'mp4 [2880p] <402>',                False,
-    '43',       'webm [360p]',                      False,
-    '44',       'webm [480p]',                      False,
-    '45',       'webm [720p]',                      False,
-    '46',       'webm [1080p]',                     False,
-    '242',      'webm [240p] (DASH Video)',         False,
-    '243',      'webm [360p] (DASH Video)',         False,
-    '244',      'webm [480p] (DASH Video)',         False,
-    '247',      'webm [720p] (DASH Video)',         False,
-    '302',      'webm [720p 60fps] (DASH Video)',   False,
-    '248',      'webm [1080p] (DASH Video)',        False,
-    '303',      'webm [1080p 60fps] (DASH Video)',  False,
-    '271',      'webm [1440p] (DASH Video)',        False,
-    '308',      'webm [1440p 60fps] (DASH Video)',  False,
-    '313',      'webm [2160p] (DASH Video)',        False,
-    '315',      'webm [2160p 60fps] (DASH Video)',  False,
-    '272',      'webm [4320p] (DASH Video)',        False,
-    '100',      'webm [360p] (3D)',                 False,
-    '101',      'webm [480p] (3D)',                 False,
-    '102',      'webm [720p] (3D)',                 False,
-    '330',      'webm [144p 60fps] (HDR)',          False,
-    '331',      'webm [240p 60fps] (HDR)',          False,
-    '332',      'webm [360p 60fps] (HDR)',          False,
-    '333',      'webm [480p 60fps] (HDR)',          False,
-    '334',      'webm [720p 60fps] (HDR)',          False,
-    '335',      'webm [1080p 60fps] (HDR)',         False,
-    '336',      'webm [1440p 60fps] (HDR)',         False,
-    '337',      'webm [2160p 60fps] (HDR)',         False,
-    '249',      'webm (50k Audio)',                 True,
-    '250',      'webm (70k Audio)',                 True,
-    '251',      'webm (160k Audio)',                True,
-    '219',      'webm [144p] <219>',                False,
-    '278',      'webm [144p] <278>',                False,
-    '167',      'webm [360p] <167>',                False,
-    '168',      'webm [480p] <168>',                False,
-    '218',      'webm [480p] <218>',                False,
-    '245',      'webm [480p] <245>',                False,
-    '246',      'webm [480p] <246>',                False,
-    '169',      'webm [1080p] <169>',               False,
-    '171',      'webm 48k (DASH Audio)',            True,
-    '172',      'webm 256k (DASH Audio)',           True,
+    '151',      'hls [72p] <151>',                          False,
+    '132',      'hls [240p] <132>',                         False,
+    '92',       'hls [240p] (3D) <92>',                     False,
+    '93',       'hls [360p] (3D) <93>',                     False,
+    '94',       'hls [480p] (3D) <94>',                     False,
+    '95',       'hls [720p] (3D) <95>',                     False,
+    '96',       'hls [1080p] <96>',                         False,
+    '139',      'm4a 48k (DASH Audio) <139>',               True,
+    '140',      'm4a 128k (DASH Audio) <140>',              True,
+    '141',      'm4a 256k (DASH Audio) <141>',              True,
+    '18',       'mp4 [360p] <18>',                          False,
+    '22',       'mp4 [720p] <22>',                          False,
+    '37',       'mp4 [1080p] <37>',                         False,
+    '38',       'mp4 [4K] <38>',                            False,
+    '160',      'mp4 [144p] (DASH Video) <160>',            False,
+    '133',      'mp4 [240p] (DASH Video) <133>',            False,
+    '134',      'mp4 [360p] (DASH Video) <134>',            False,
+    '135',      'mp4 [480p] (DASH Video) <135>',            False,
+    '136',      'mp4 [720p] (DASH Video) <136>',            False,
+    '298',      'mp4 [720p 60fps] (DASH Video) <298>',      False,
+    '137',      'mp4 [1080p] (DASH Video) <137>',           False,
+    '299',      'mp4 [1080p 60fps] (DASH Video) <299>',     False,
+    '264',      'mp4 [1440p] (DASH Video) <264>',           False,
+    '138',      'mp4 [2160p] (DASH Video) <138>',           False,
+    '266',      'mp4 [2160p 60fps] (DASH Video) <266>',     False,
+    '82',       'mp4 [360p] (3D) <82>',                     False,
+    '83',       'mp4 [480p] (3D) <83>',                     False,
+    '84',       'mp4 [720p] (3D) <84>',                     False,
+    '85',       'mp4 [1080p] (3D) <85>',                    False,
+    '394',      'mp4 [144p] <394>',                         False,
+    '395',      'mp4 [240p] <395>',                         False,
+    '396',      'mp4 [360p] <396>',                         False,
+    '397',      'mp4 [480p] <397>',                         False,
+    '398',      'mp4 [720p] <398>',                         False,
+    '399',      'mp4 [1080p] <399>',                        False,
+    '400',      'mp4 [1440p] <400>',                        False,
+    '401',      'mp4 [2160p] <401>',                        False,
+    '402',      'mp4 [2880p] <402>',                        False,
+    '43',       'webm [360p] <43>',                         False,
+    '44',       'webm [480p] <44>',                         False,
+    '45',       'webm [720p] <45>',                         False,
+    '46',       'webm [1080p] <46>',                        False,
+    '242',      'webm [240p] (DASH Video) <242>',           False,
+    '243',      'webm [360p] (DASH Video) <243>',           False,
+    '244',      'webm [480p] (DASH Video) <244>',           False,
+    '247',      'webm [720p] (DASH Video) <247>',           False,
+    '302',      'webm [720p 60fps] (DASH Video) <302>',     False,
+    '248',      'webm [1080p] (DASH Video) <248>',          False,
+    '303',      'webm [1080p 60fps] (DASH Video) <303>',    False,
+    '271',      'webm [1440p] (DASH Video) <271>',          False,
+    '308',      'webm [1440p 60fps] (DASH Video) <300>',    False,
+    '313',      'webm [2160p] (DASH Video) <313>',          False,
+    '315',      'webm [2160p 60fps] (DASH Video) <315>',    False,
+    '272',      'webm [4320p] (DASH Video) <272>',          False,
+    '100',      'webm [360p] (3D) <100>',                   False,
+    '101',      'webm [480p] (3D) <101>',                   False,
+    '102',      'webm [720p] (3D) <102>',                   False,
+    '330',      'webm [144p 60fps] (HDR) <330>',            False,
+    '331',      'webm [240p 60fps] (HDR) <331>',            False,
+    '332',      'webm [360p 60fps] (HDR) <332>',            False,
+    '333',      'webm [480p 60fps] (HDR) <333>',            False,
+    '334',      'webm [720p 60fps] (HDR) <334>',            False,
+    '335',      'webm [1080p 60fps] (HDR) <335>',           False,
+    '336',      'webm [1440p 60fps] (HDR) <336>',           False,
+    '337',      'webm [2160p 60fps] (HDR) <337>',           False,
+    '600',      'webm (36k Audio) <600>',                   True,
+    '249',      'webm (52k Audio) <249>',                   True,
+    '250',      'webm (64k Audio) <250>',                   True,
+    '251',      'webm (116k Audio) <251>',                  True,
+    '219',      'webm [144p] <219>',                        False,
+    '278',      'webm [144p] <278>',                        False,
+    '167',      'webm [360p] <167>',                        False,
+    '168',      'webm [480p] <168>',                        False,
+    '218',      'webm [480p] <218>',                        False,
+    '245',      'webm [480p] <245>',                        False,
+    '246',      'webm [480p] <246>',                        False,
+    '169',      'webm [1080p] <169>',                       False,
+    '171',      'webm 48k (DASH Audio) <171>',              True,
+    '172',      'webm 256k (DASH Audio) <172>',             True,
 ]
 
 VIDEO_OPTION_LIST = []
-VIDEO_ONLY_OPTION_LIST = []
 VIDEO_OPTION_DICT = {}
+VIDEO_OPTION_TYPE_DICT = {}
 
 while video_option_setup_list:
     value = video_option_setup_list.pop(0)
@@ -281,8 +279,7 @@ while video_option_setup_list:
 
     VIDEO_OPTION_LIST.append(key)
     VIDEO_OPTION_DICT[key] = value
-    if not audio_only_flag:
-        VIDEO_ONLY_OPTION_LIST.append(key)
+    VIDEO_OPTION_TYPE_DICT[value] = audio_only_flag
 
 video_resolution_setup_list = [
     '144p',     '144',
@@ -314,7 +311,7 @@ while video_resolution_setup_list:
 
 VIDEO_FPS_DICT = {
     # Contains a subset of VIDEO_RESOLUTION_DICT. Only required to distinguish
-    #   30fps from 60fps formats, so this
+    #   30fps from 60fps formats
     '720p60':   '60',
     '1080p60':  '60',
     '1440p60':  '60',
